#
# spec file for package ebtables
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#



Name:           ebtables
Version:        2.0.10.3
Release:        1.11
License:        GPL-2.0+
Summary:        Ethernet Bridge Tables
URL:            http://ebtables.sf.net/
Group:          Productivity/Networking/Security
Source:         %name-v2.0.10-3.tar.xz
Patch0:         %name-v2.0.8-makefile.diff
Patch1:         %name-v2.0.8-initscript.diff
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  xz
%if 0%{?fedora} || 0%{?rhel}
BuildRequires:  kernel-headers
%endif

%description
A firewalling tool to transparently filter network traffic passing a
bridge. The filtering possibilities are limited to link layer filtering
and some basic filtering on higher network layers. The ebtables tool
can be used together with the other Linux filtering tools, like
iptables. There are no incompatibility issues.

%prep
%if 0%{?__xz:1}
%setup -q -n %name-v2.0.10-3
%else
tar -xf "%{S:0}" --use=xz;
%setup -DTqn %name-v2.0.10-3
%endif
%patch0
%patch1

%build
# The way ebtables is built requires ASNEEDED=0 forever [bnc#567267]
export SUSE_ASNEEDED=0
# delete all kernel headers, but keep ebt_ip6.h and ebt_nflog.h
mv include/linux/netfilter_bridge/ebt_ip6.{h,h.save}
mv include/linux/netfilter_bridge/ebt_nflog.{h,h.save}
rm -f include/linux/*.h
rm -f include/linux/netfilter_bridge/*.h
mv include/linux/netfilter_bridge/ebt_ip6.{h.save,h}
mv include/linux/netfilter_bridge/ebt_nflog.{h.save,h}
make \
    CFLAGS="%optflags" \
    CXXFLAGS="%optflags" \
    LIBDIR=%_libdir/%name \
    MANDIR=%_mandir \
    BINDIR=%_sbindir \
    ETCDIR=%_sysconfdir \
    INITDIR=%_sysconfdir/init.d \
    SYSCONFIGDIR=%_sysconfdir

%install
# The way ebtables is built requires ASNEEDED=0 forever [bnc#567267]
export SUSE_ASNEEDED=0
install -d -m 755 %buildroot%_sbindir
install -d -m 755 %buildroot%_sysconfdir/init.d
make \
    DESTDIR=%buildroot \
    LIBDIR=%_libdir/%name \
    MANDIR=%_mandir \
    BINDIR=%_sbindir \
    ETCDIR=%_sysconfdir \
    INITDIR=%_sysconfdir/init.d \
    SYSCONFIGDIR=%_sysconfdir \
    install
ln -sf %_sysconfdir/init.d/ebtables %buildroot%_sbindir/rcebtables
# not used
rm -f %buildroot%_sysconfdir/ebtables-config

%post
%fillup_and_insserv ebtables

%preun
%stop_on_removal ebtables

%postun
%restart_on_update ebtables
%insserv_cleanup

%files
%defattr(-,root,root)
%doc COPYING ChangeLog
%doc %_mandir/man8/ebtables.8*
%config(noreplace) %_sysconfdir/ethertypes
%_sysconfdir/init.d/ebtables
%dir %_libdir/%name
%_libdir/%name/*.so
%_sbindir/ebtables
%_sbindir/ebtables-restore
%_sbindir/ebtables-save
%_sbindir/rcebtables

%changelog
* Sun Dec  4 2011 jengelh@medozas.de
- Update to new upstream release 2.0.10.3
  * fix a counter setting bug
* Thu Aug 11 2011 jengelh@medozas.de
- Update to new upstream release 2.0.10.2
  * minor compilation fixes: respect LDFLAGS in Makefiles
- Remove obsolete ebtables-typepuns.diff patch (fixed upstream)
* Sun Jul 10 2011 jengelh@medozas.de
- update to 2.0.10.1
  * fix --among-dst-file, which translated to --among-src
  * Makefile: respect LDFLAGS during ebtables build
  * Makefile: create directories to avoid build failure when DESTDIR
  is supplied
  * incorporate fixes for possible issues found by Coverity analysis
  * extend ebt_ip6 to allow matching on ipv6-icmp types/codes
  * add --concurrent option, which enables using a file lock to
  support concurrent scripts updating the ebtables kernel tables
- run spec-beautifier over specfile
* Mon Jun  6 2011 puzel@novell.com
- update to 2.0.9-2
  * fix unwanted zeroing of counters in the last user-defined chain
  * fix hidden symbol compilation error when using ld directly
  * fix return value checking of creat to give a correct error
    message if the atomic file couldn't be created
  * correct info in INSTALL about compilation of ulog
- use spec-cleaner
- update ebtables-v2.0.8-makefile.diff
- license is GPLv2, not GPLv2+
- package COPYING and ChangeLog files
* Tue May 31 2011 lnussel@suse.de
- cleanup up initscript
  * don't use /var/lock/subsys
  * read /etc/sysconfig/ebtables for setting and restore state from
    /etc/ebtables where the script actually saved the state to.
* Thu Mar 18 2010 coolo@novell.com
- use rc_status (uncredited change)
* Mon Jan 25 2010 jengelh@medozas.de
- Switch to SUSE_ASNEEDED=0 to fix segmentation fault/NULL dereference
  (caused by plugins not being loaded, due to them not being linked in)
  [bnc#567267]
* Wed Jan  6 2010 prusnak@suse.cz
- update to 2.0.9-1
  * added ip6 module for filtering IPv6 traffic
  * added --log-ip6 option for logging IPv6 traffic
  * added nflog watcher for logging packets to userspace
  * bugfix in ebtables.sysv
  * bugfix for among match on x86-64
- fix scriptlets in spec
- fix init script
* Sat Aug 30 2008 cthiel@suse.de
- fix init script
* Wed Oct 24 2007 ro@suse.de
- fix build (use gcc not ld directly)
* Wed Oct 17 2007 prusnak@suse.cz
- fixed specfile not to include debug files in normal package
* Fri Oct 12 2007 prusnak@suse.cz
- update to 2.0.8-2
  * add sysconfig support (ebtables-save, ebtables-restore, etc)
  * add ulog watcher
  * use shared libraries (making the code easily usable by third parties)
  * improve speed
  * bugfixes, dccp and sctp support
- dropped obsolete patches:
  * gcc.diff (included in update)
* Thu Aug  9 2007 olh@suse.de
- remove private include/linux/ files
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jun 29 2005 meissner@suse.de
- use RPM_OPT_FLAGS.
* Thu Apr 21 2005 postadal@suse.cz
- fixed for gcc 4.0
* Fri Jun 18 2004 postadal@suse.cz
- new package v2.0.6
